==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/LineAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation that draws a simple line on a page.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for LineAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="LineAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseAnnotationType">
 *       <all>
 *         <element name="start" type="{http://schema.webpdf.de/1.0/operation}PointType"/>
 *         <element name="end" type="{http://schema.webpdf.de/1.0/operation}PointType"/>
 *         <element name="border" type="{http://schema.webpdf.de/1.0/operation}BorderType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LineAnnotationType", propOrder = {
    "start",
    "end",
    "border"
})
public class LineAnnotationType
    extends BaseAnnotationType
{

    @XmlElement(required = true)
    protected PointType start;
    @XmlElement(required = true)
    protected PointType end;
    protected BorderType border;

    /**
     * Gets the value of the start property.
     * 
     * @return
     *     possible object is
     *     {@link PointType }
     *     
     */
    public PointType getStart() {
        return start;
    }

    /**
     * Sets the value of the start property.
     * 
     * @param value
     *     allowed object is
     *     {@link PointType }
     *     
     */
    public void setStart(PointType value) {
        this.start = value;
    }

    public boolean isSetStart() {
        return (this.start!= null);
    }

    /**
     * Gets the value of the end property.
     * 
     * @return
     *     possible object is
     *     {@link PointType }
     *     
     */
    public PointType getEnd() {
        return end;
    }

    /**
     * Sets the value of the end property.
     * 
     * @param value
     *     allowed object is
     *     {@link PointType }
     *     
     */
    public void setEnd(PointType value) {
        this.end = value;
    }

    public boolean isSetEnd() {
        return (this.end!= null);
    }

    /**
     * Gets the value of the border property.
     * 
     * @return
     *     possible object is
     *     {@link BorderType }
     *     
     */
    public BorderType getBorder() {
        return border;
    }

    /**
     * Sets the value of the border property.
     * 
     * @param value
     *     allowed object is
     *     {@link BorderType }
     *     
     */
    public void setBorder(BorderType value) {
        this.border = value;
    }

    public boolean isSetBorder() {
        return (this.border!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/LineAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation that draws a simple line on a page.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for LineAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="LineAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseAnnotationType">
 *       <all>
 *         <element name="start" type="{http://schema.webpdf.de/1.0/operation}PointType"/>
 *         <element name="end" type="{http://schema.webpdf.de/1.0/operation}PointType"/>
 *         <element name="border" type="{http://schema.webpdf.de/1.0/operation}BorderType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LineAnnotationType", propOrder = {
    "start",
    "end",
    "border"
})
public class LineAnnotationType
    extends BaseAnnotationType
{

    @XmlElement(required = true)
    protected PointType start;
    @XmlElement(required = true)
    protected PointType end;
    protected BorderType border;

    /**
     * Gets the value of the start property.
     * 
     * @return
     *     possible object is
     *     {@link PointType }
     *     
     */
    public PointType getStart() {
        return start;
    }

    /**
     * Sets the value of the start property.
     * 
     * @param value
     *     allowed object is
     *     {@link PointType }
     *     
     */
    public void setStart(PointType value) {
        this.start = value;
    }

    public boolean isSetStart() {
        return (this.start!= null);
    }

    /**
     * Gets the value of the end property.
     * 
     * @return
     *     possible object is
     *     {@link PointType }
     *     
     */
    public PointType getEnd() {
        return end;
    }

    /**
     * Sets the value of the end property.
     * 
     * @param value
     *     allowed object is
     *     {@link PointType }
     *     
     */
    public void setEnd(PointType value) {
        this.end = value;
    }

    public boolean isSetEnd() {
        return (this.end!= null);
    }

    /**
     * Gets the value of the border property.
     * 
     * @return
     *     possible object is
     *     {@link BorderType }
     *     
     */
    public BorderType getBorder() {
        return border;
    }

    /**
     * Sets the value of the border property.
     * 
     * @param value
     *     allowed object is
     *     {@link BorderType }
     *     
     */
    public void setBorder(BorderType value) {
        this.border = value;
    }

    public boolean isSetBorder() {
        return (this.border!= null);
    }

}
